@@ -402,14 +402,20 @@ class DefaultAlgorithm(AutoMLAlgorithm):
         self._batch_number += 1
         return next_batch
 
-    def add_result(self, score_to_minimize, pipeline, trained_pipeline_results):
+    def add_result(
+        self, score_to_minimize, pipeline, trained_pipeline_results, cached_data=None
+    ):
         """Register results from evaluating a pipeline. In batch number 2, the selected column names from the feature selector are taken to be used in a column selector. Information regarding the best pipeline is updated here as well.
 
         Args:
             score_to_minimize (float): The score obtained by this pipeline on the primary objective, converted so that lower values indicate better pipelines.
             pipeline (PipelineBase): The trained pipeline object which was used to compute the score.
             trained_pipeline_results (dict): Results from training a pipeline.
+            cached_data (dict): A dictionary of cached data, where the keys are the model family. Expected to be of format
+                {model_family: {hash1: trained_component_graph, hash2: trained_component_graph...}...}.
+                Defaults to None.
         """
+        cached_data = cached_data or {}
         if pipeline.model_family != ModelFamily.ENSEMBLE:
             if self.batch_number >= 3:
                 super().add_result(
@@ -457,6 +463,7 @@ class DefaultAlgorithm(AutoMLAlgorithm):
                         "pipeline": pipeline,
                         "parameters": pipeline.parameters,
                         "id": trained_pipeline_results["id"],
+                        "cached_data": cached_data,
                     }
                 }
             )
