@@ -6,9 +6,14 @@ from woodwork.logical_types import Boolean, Categorical, Double, Integer
 from evalml.pipelines.components import StandardScaler
 
 
-@pytest.mark.parametrize("X_df", [pd.DataFrame(pd.Series([1, 2, 3], dtype="Int64")),
-                                  pd.DataFrame(pd.Series([1., 2., 3.], dtype="float")),
-                                  pd.DataFrame(pd.Series([True, False, True], dtype="boolean"))])
+@pytest.mark.parametrize(
+    "X_df",
+    [
+        pd.DataFrame(pd.Series([1, 2, 3], dtype="Int64")),
+        pd.DataFrame(pd.Series([1.0, 2.0, 3.0], dtype="float")),
+        pd.DataFrame(pd.Series([True, False, True], dtype="boolean")),
+    ],
+)
 def test_standard_scaler_woodwork_custom_overrides_returned_by_components(X_df):
     y = pd.Series([1, 2, 1])
     override_types = [Integer, Double, Categorical, Boolean]
@@ -22,4 +27,6 @@ def test_standard_scaler_woodwork_custom_overrides_returned_by_components(X_df):
         std_scaler.fit(X_df, y)
         transformed = std_scaler.transform(X_df, y)
         assert isinstance(transformed, pd.DataFrame)
-        assert transformed.ww.logical_types == {0: Double}
+        assert {k: type(v) for k, v in transformed.ww.logical_types.items()} == {
+            0: Double
+        }
