@@ -111,10 +111,7 @@ def test_make_pipeline(
             assert isinstance(pipeline, pipeline_class)
             label_encoder = [LabelEncoder] if is_classification(problem_type) else []
             delayed_features = (
-                [TimeSeriesFeaturizer]
-                if is_time_series(problem_type)
-                and estimator_class.model_family != ModelFamily.ARIMA
-                else []
+                [TimeSeriesFeaturizer] if is_time_series(problem_type) else []
             )
 
             if estimator_class.model_family != ModelFamily.CATBOOST and any(
