@@ -6,8 +6,6 @@ import struct
 import sys
 
 import pkg_resources
-import psutil
-from psutil._common import bytes2human
 
 import evalml
 from evalml.utils import get_logger
@@ -66,13 +64,6 @@ def get_sys_info():
                 ("LC_ALL", "{lc}".format(lc=os.environ.get("LC_ALL", "None"))),
                 ("LANG", "{lang}".format(lang=os.environ.get("LANG", "None"))),
                 ("LOCALE", ".".join(map(str, locale.getlocale()))),
-                ("# of CPUS", "{cpus}".format(cpus=psutil.cpu_count())),
-                (
-                    "Available memory",
-                    "{memory}".format(
-                        memory=bytes2human(psutil.virtual_memory().available)
-                    ),
-                ),
             ]
         )
     except (KeyError, ValueError):
